"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class IPService {
    constructor($config, $httpClient, $logger) {
        this.$config = $config;
        this.$httpClient = $httpClient;
        this.$logger = $logger;
    }
    getCurrentIPv4Address() {
        return __awaiter(this, void 0, void 0, function* () {
            const ipAddress = (yield this.getIPAddressFromServiceReturningJSONWithIPProperty(this.$config.WHOAMI_URL_ENDPOINT)) ||
                (yield this.getIPAddressFromServiceReturningJSONWithIPProperty("https://api.myip.com")) ||
                (yield this.getIPAddressFromIpifyOrgAPI()) ||
                null;
            return ipAddress;
        });
    }
    getIPAddressFromServiceReturningJSONWithIPProperty(apiEndpoint) {
        return __awaiter(this, void 0, void 0, function* () {
            let ipAddress = null;
            try {
                const response = yield this.$httpClient.httpRequest({
                    method: "GET",
                    url: apiEndpoint,
                    timeout: IPService.GET_IP_TIMEOUT
                });
                this.$logger.trace(`${apiEndpoint} returns ${response.body}`);
                const jsonData = JSON.parse(response.body);
                ipAddress = jsonData.ip;
            }
            catch (err) {
                this.$logger.trace(`Unable to get information about current IP Address from ${apiEndpoint} Error is:`, err);
            }
            return ipAddress;
        });
    }
    getIPAddressFromIpifyOrgAPI() {
        return __awaiter(this, void 0, void 0, function* () {
            const ipifyOrgAPIEndpoint = "https://api.ipify.org";
            let ipAddress = null;
            try {
                const response = yield this.$httpClient.httpRequest({
                    method: "GET",
                    url: ipifyOrgAPIEndpoint,
                    timeout: IPService.GET_IP_TIMEOUT
                });
                this.$logger.trace(`${ipifyOrgAPIEndpoint} returns ${response.body}`);
                ipAddress = (response.body || '').toString();
            }
            catch (err) {
                this.$logger.trace(`Unable to get information about current IP Address from ${ipifyOrgAPIEndpoint} Error is:`, err);
            }
            return ipAddress;
        });
    }
}
IPService.GET_IP_TIMEOUT = 1000;
exports.IPService = IPService;
$injector.register("ipService", IPService);
